Index: legacy/includes/news.inc
===================================================================
--- legacy/includes/news.inc	(revision 34838)
+++ legacy/includes/news.inc	(working copy)
@@ -133,7 +133,7 @@
   if(!$_POST['submit']) {
     echo "<p>Use the form below to add project news.</p>\n\n";
     echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
-    echo "<p>Title:&nbsp;&nbsp;<input type=\"text\" name=\"title\" size=\"40\" /></p>\n";
+    echo "<p>Title:&#160;&#160;<input type=\"text\" name=\"title\" size=\"40\" /></p>\n";
     echo "<p>News:</p>\n";
     echo "<p><textarea name=\"news\" cols=\"70\" rows=\"20\"></textarea></p>\n";
     echo "<p><input type=\"submit\" name=\"submit\" value=\"Submit\" /></p>\n";
@@ -190,7 +190,7 @@
       $row = mysql_fetch_object($result);
       echo "<p>Use the form below to edit project news.</p>\n\n";
       echo "<form action=\"$PHP_SELF?id=$id\" method=\"post\">\n";
-      echo "<p>Title:&nbsp;&nbsp;<input type=\"text\" name=\"title\" size=\"40\" value=\"$row->title\" /></p>\n";
+      echo "<p>Title:&#160;&#160;<input type=\"text\" name=\"title\" size=\"40\" value=\"$row->title\" /></p>\n";
       echo "<p>News:</p>\n";
       echo "<p><textarea name=\"news\" cols=\"70\" rows=\"20\">";
       echo htmlentities($row->news);
@@ -253,7 +253,7 @@
   }
   if(mysql_num_rows($result) > 0) {
     while($row = mysql_fetch_object($result)) {
-      echo "<p><a href=\"/macports/archives.php?id=$row->id\">$row->title</a><br />&nbsp&nbsp;$row->f_timestamp&nbsp;&nbsp;|&nbsp;&nbsp;
+      echo "<p><a href=\"/macports/archives.php?id=$row->id\">$row->title</a><br />&#160;&#160;$row->f_timestamp&#160;&#160;|&#160;&#160;
            <a href=\"/macports/admin/edit.php?id=$row->id\">edit</a></p>\n\n";
     }
   }
@@ -276,7 +276,7 @@
   }
   if(mysql_num_rows($result) > 0) {
     while($row = mysql_fetch_object($result)) {
-      echo "<p><a href=\"/macports/archives.php?id=$row->id\">$row->title</a><br />&nbsp&nbsp;$row->f_timestamp</p>\n\n";
+      echo "<p><a href=\"/macports/archives.php?id=$row->id\">$row->title</a><br />&#160;&#160;$row->f_timestamp</p>\n\n";
     }
   }
   else {
Index: includes/header.inc
===================================================================
--- includes/header.inc	(revision 34838)
+++ includes/header.inc	(working copy)
@@ -44,7 +44,7 @@
             <span id="languages">
                 <a href="#"><img src="img/fr-disabled.png" alt="Fran&#xE7;ais" /></a>
                 <a href="#"><img src="img/es-disabled.png" alt="Espa&#xF1;ol" /></a>
-                <a href="#"><img src="img/ru-disabled.png" alt="&#1056;&#1091;&#1089;&#1089;&#1082;&#1080;&#1081;&nbsp;(Russkij)"/></a>
+                <a href="#"><img src="img/ru-disabled.png" alt="&#1056;&#1091;&#1089;&#1089;&#1082;&#1080;&#1081;&#160;(Russkij)"/></a>
                 <a href="#"><img src="img/it-disabled.png" alt="Italiano" /></a>
             </span>
         </div>
Index: localized/ru/getdp/index.php
===================================================================
--- localized/ru/getdp/index.php	(revision 34838)
+++ localized/ru/getdp/index.php	(working copy)
@@ -8,7 +8,7 @@
       <h2 class="hdr">Получить DarwinPorts</h2>
 
       <p>Для того, что-бы получить дистрибутив DarwinPorts, сначала необходимо
-      сделать &ldquo;checked out&rdquo; из CVS репозитария проекта OpenDarwin.</p>
+      сделать &#8220;checked out&#8221; из CVS репозитария проекта OpenDarwin.</p>
 
       <p>Пожалуйста, имейте ввиду, что для получения и установки DarwinPorts на
       систему Mac OS X, у Вас должны быть установлены Mac OS X Developer Tools (
Index: localized/ru/includes/functions.inc
===================================================================
--- localized/ru/includes/functions.inc	(revision 34838)
+++ localized/ru/includes/functions.inc	(working copy)
@@ -128,7 +128,7 @@
   if(!$_POST['submit']) {
     echo "<p>Use the form below to add project news.</p>\n\n";
     echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
-    echo "<p>Title:&nbsp;&nbsp;<input type=\"text\" name=\"title\" size=\"40\" /></p>\n";
+    echo "<p>Title:&#160;&#160;<input type=\"text\" name=\"title\" size=\"40\" /></p>\n";
     echo "<p>News:</p>\n";
     echo "<p><textarea name=\"news\" cols=\"70\" rows=\"20\"></textarea></p>\n";
     echo "<p><input type=\"submit\" name=\"submit\" value=\"Submit\" /></p>\n";
@@ -184,7 +184,7 @@
       $row = mysql_fetch_object($result);
       echo "<p>Use the form below to edit project news.</p>\n\n";
       echo "<form action=\"$PHP_SELF?id=$id\" method=\"post\">\n";
-      echo "<p>Title:&nbsp;&nbsp;<input type=\"text\" name=\"title\" size=\"40\" value=\"$row->title\" /></p>\n";
+      echo "<p>Title:&#160;&#160;<input type=\"text\" name=\"title\" size=\"40\" value=\"$row->title\" /></p>\n";
       echo "<p>News:</p>\n";
       echo "<p><textarea name=\"news\" cols=\"70\" rows=\"20\">";
       echo htmlentities($row->news);
@@ -245,7 +245,7 @@
   }
   if(mysql_num_rows($result) > 0) {
     while($row = mysql_fetch_object($result)) {
-      echo "<p><a href=\"/archives/$row->id.php\">$row->title</a><br />&nbsp&nbsp;$row->f_timestamp&nbsp;&nbsp;|&nbsp;&nbsp;<a href=\"edit.php?id=$row->id\">edit</a></p>\n\n";
+      echo "<p><a href=\"/archives/$row->id.php\">$row->title</a><br />&#160;&#160;$row->f_timestamp&#160;&#160;|&#160;&#160;<a href=\"edit.php?id=$row->id\">edit</a></p>\n\n";
     }
   }
   else {
Index: localized/es/getdp/index.php
===================================================================
--- localized/es/getdp/index.php	(revision 34838)
+++ localized/es/getdp/index.php	(working copy)
@@ -45,7 +45,7 @@
 
 		<p>Aunque no es estrictamente necesario, se recomienda de todas formas sincronizar la reciente
 		instalación de DarwinPorts con nuestro servidor de rsync para asegurar la disponibilidad de
-		la última versión de la infraestructura de DarwinPorts y de los &ldquo;Portfiles&rdquo; que
+		la última versión de la infraestructura de DarwinPorts y de los &#8220;Portfiles&#8221; que
 		que contienen las instrucciones empleadas en la compilación e instalación de portes.
 		Para lograr esto, simplemente ejecute:</p>
 
@@ -58,9 +58,9 @@
 
 		<p>Si en cambio Ud. desea instalar DarwinPorts a partir de su código fuente, hay todavía un par de
 		cosas que deberá hacer después de bajar el paquete tar antes de poder instalar un porte a través de DarwinPorts,
-		compilar e instalar DarwinPorts en sí. &ldquo;<kbd>cd</kbd>&rdquo; al directorio al cual bajó el tar y corra
-		&ldquo;<kbd>tar xjvf <a href="/downloads/DarwinPorts-<? print "$dp_version"; ?>.tar.bz2">DarwinPorts-<? print "$dp_version"; ?>.tar.bz2</a></kbd>&rdquo;
-		o &ldquo;<kbd>tar xzvf <a href="/downloads/DarwinPorts-<? print "$dp_version"; ?>.tar.gz">DarwinPorts-<? print "$dp_version"; ?>.tar.gz</a></kbd>&rdquo;,
+		compilar e instalar DarwinPorts en sí. &#8220;<kbd>cd</kbd>&#8221; al directorio al cual bajó el tar y corra
+		&#8220;<kbd>tar xjvf <a href="/downloads/DarwinPorts-<? print "$dp_version"; ?>.tar.bz2">DarwinPorts-<? print "$dp_version"; ?>.tar.bz2</a></kbd>&#8221;
+		o &#8220;<kbd>tar xzvf <a href="/downloads/DarwinPorts-<? print "$dp_version"; ?>.tar.gz">DarwinPorts-<? print "$dp_version"; ?>.tar.gz</a></kbd>&#8221;,
 		dependiendo de si bajó el tar bz2 o el gz, respectivamente. Esto desempaquetará las fuentes de DarwinPorts
 		que procederá a compilar e instalar. Para esto, ejecute lo siguiente:</p>
 
@@ -73,11 +73,11 @@
 		<pre>cd ../
 rm -rf DarwinPorts-<? print "$dp_version"; ?>*</pre>
 
-		<p>Estos pasos deben ser ejecutados desde una cuenta administradora, de la cual &ldquo;<kbd>sudo</kbd>&rdquo;
+		<p>Estos pasos deben ser ejecutados desde una cuenta administradora, de la cual &#8220;<kbd>sudo</kbd>&#8221;
 		pedirá el password al momento de instalar. Este procedimiento creará una instalación standard de DarwinPorts
 		en su sistema y, si los pasos opcionales son ejecutados también, removerá las ahora innecesarias fuentes de
 		DarwinPorts y el correspondiente paquete tar. Para personalizar su instalación debe leer el output de
-		&ldquo;<kbd>./configure --help | more</kbd>&rdquo; y pasar las opciones apropiadas al script de configuración
+		&#8220;<kbd>./configure --help | more</kbd>&#8221; y pasar las opciones apropiadas al script de configuración
 		en los pasos arriba detallados.</p>
 
 		<p>Deberá adaptar los documentos de configuración de su shell para encontrar los programas instalados por
@@ -88,7 +88,7 @@
 		<p>Al completar, DarwinPorts estará listo para instalar portes. Nuevamente, es recomendado ejecutar el comando
 		anterior regularmente para mantener su instalación siempre al día.</p>
 
-		<p>También puede referirse al documento &ldquo;<tt>README_RELEASE1.es</tt>&rdquo; contenido en los paquetes tar de las fuentes
+		<p>También puede referirse al documento &#8220;<tt>README_RELEASE1.es</tt>&#8221; contenido en los paquetes tar de las fuentes
 		<? print "$dp_version"; ?> de DarwinPorts para instrucciones básicas de instalación y uso.</p>
 
 		<h5 class="subhdr">Ayuda</h5>
@@ -100,7 +100,7 @@
 		<p>Si Ud. es un programador o un usuario que desea mantenerse siempre al día con los últimos cambios y adiciones
 		a DarwinPorts, puede adquirir las fuentes del proyecto a través de CVS.</p>
 
-		<p>Use los siguientes comandos para realizar el &ldquo;checkout&rdquo; del proyecto del
+		<p>Use los siguientes comandos para realizar el &#8220;checkout&#8221; del proyecto del
 		repositorio anónimo CVS de OpenDarwin:</p>
 		
 		<pre>cvs -d :pserver:anonymous@anoncvs.opendarwin.org:/Volumes/src/cvs/od login
@@ -111,9 +111,9 @@
 		
 		<p>Si no se quiere molestar con CVS para obtener las fuentes en primera instancia, puede bajar el <a href="/downloads/darwinports-nightly-cvs-snapshot.tar.gz">
 		snapshot nocturno</a> de éstas y, una vez extraído, mantenerlo actualizado con los comandos de CVS de costumbre,
-		&ldquo;<kbd>cvs update</kbd>&rdquo;.</p>
+		&#8220;<kbd>cvs update</kbd>&#8221;.</p>
 		
-		<p>Si desea simplemente ver el repositorio CVS sin realizar un &ldquo;checkout&rdquo;,
+		<p>Si desea simplemente ver el repositorio CVS sin realizar un &#8220;checkout&#8221;,
 		lo puede hacer vía <a href="http://www.opendarwin.org/cgi-bin/cvsweb.cgi/proj/darwinports/">CVSweb</a>.</p>
 	
 	</div>
Index: localized/es/includes/functions.inc
===================================================================
--- localized/es/includes/functions.inc	(revision 34838)
+++ localized/es/includes/functions.inc	(working copy)
@@ -130,7 +130,7 @@
 			if (!$_POST['submit']) {
 				echo "<p>Utilice el formulario que se presenta abajo para agregar noticias del proyecto.</p>\n\n";
 				echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
-				echo "<p>Título:&nbsp;&nbsp;<input type=\"text\" name=\"title\" size=\"40\" /></p>\n";
+				echo "<p>Título:&#160;&#160;<input type=\"text\" name=\"title\" size=\"40\" /></p>\n";
 				echo "<p>Noticias:</p>\n";
 				echo "<p><textarea name=\"news\" cols=\"70\" rows=\"20\"></textarea></p>\n";
 				echo "<p><input type=\"submit\" name=\"submit\" value=\"Remitir\" /></p>\n";
@@ -185,7 +185,7 @@
 					$row = mysql_fetch_object($result);
 					echo "<p>Use el formulario abajo mostrado para editar las noticias del proyecto.</p>\n\n";
 					echo "<form action=\"$PHP_SELF?id=$id\" method=\"post\">\n";
-					echo "<p>Título:&nbsp;&nbsp;<input type=\"text\" name=\"title\" size=\"40\" value=\"$row->title\" /></p>\n";
+					echo "<p>Título:&#160;&#160;<input type=\"text\" name=\"title\" size=\"40\" value=\"$row->title\" /></p>\n";
 					echo "<p>Noticias:</p>\n";
 					echo "<p><textarea name=\"news\" cols=\"70\" rows=\"20\">";
 					echo htmlentities($row->news);
@@ -242,7 +242,7 @@
 			}
 			if (mysql_num_rows($result) > 0) {
 				while ($row = mysql_fetch_object($result)) {
-					echo "<p><a href=\"/es/archives.php?id=$row->id.php\">$row->title</a><br />&nbsp&nbsp;$row->f_timestamp&nbsp;&nbsp;|&nbsp;&nbsp;<a href=\"edit.php?id=$row->id\">editar</a></p>\n\n";
+					echo "<p><a href=\"/es/archives.php?id=$row->id.php\">$row->title</a><br />&#160;&#160;$row->f_timestamp&#160;&#160;|&#160;&#160;<a href=\"edit.php?id=$row->id\">editar</a></p>\n\n";
 				}
 			} else {
 				echo "<p>No hay titulares disponibles.</p>\n\n";
@@ -264,7 +264,7 @@
 	 }
 	 if (mysql_num_rows($result)>0) {
 	    while ($row = mysql_fetch_object($result)) {
-		  echo "<p><a href=\"/es/archives.php?id=$row->id\">$row->title</a><br />&nbsp&nbsp;$row->f_timestamp</p>\n\n";
+		  echo "<p><a href=\"/es/archives.php?id=$row->id\">$row->title</a><br />&#160;&#160;$row->f_timestamp</p>\n\n";
 		}
 	} else {
 		  echo "<p>No hay titulares disponibles.</p>\n\n";
Index: localized/fr/includes/functions.inc
===================================================================
--- localized/fr/includes/functions.inc	(revision 34838)
+++ localized/fr/includes/functions.inc	(working copy)
@@ -128,7 +128,7 @@
   if(!$_POST['submit']) {
     echo "<p>Utilisez le formulaire ci-dessous pour ajouter une dépêche liée au projet.</p>\n\n";
     echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
-    echo "<p>Title:&nbsp;&nbsp;<input type=\"text\" name=\"title\" size=\"40\" /></p>\n";
+    echo "<p>Title:&#160;&#160;<input type=\"text\" name=\"title\" size=\"40\" /></p>\n";
     echo "<p>Dépêche :</p>\n";
     echo "<p><textarea name=\"news\" cols=\"70\" rows=\"20\"></textarea></p>\n";
     echo "<p><input type=\"submit\" name=\"submit\" value=\"Soumettre\" /></p>\n";
@@ -184,7 +184,7 @@
       $row = mysql_fetch_object($result);
       echo "<p>Utilisez le formulaire ci-dessous pour éditer les dépêches du projet.</p>\n\n";
       echo "<form action=\"$PHP_SELF?id=$id\" method=\"post\">\n";
-      echo "<p>Title:&nbsp;&nbsp;<input type=\"text\" name=\"title\" size=\"40\" value=\"$row->title\" /></p>\n";
+      echo "<p>Title:&#160;&#160;<input type=\"text\" name=\"title\" size=\"40\" value=\"$row->title\" /></p>\n";
       echo "<p>Dépêche :</p>\n";
       echo "<p><textarea name=\"news\" cols=\"70\" rows=\"20\">";
       echo htmlentities($row->news);
@@ -245,7 +245,7 @@
   }
   if(mysql_num_rows($result) > 0) {
     while($row = mysql_fetch_object($result)) {
-      echo "<p><a href=\"/fr/archives.php?id=$row->id\">$row->title</a><br />&nbsp&nbsp;$row->f_timestamp&nbsp;&nbsp;|&nbsp;&nbsp;<a href=\"edit.php?id=$row->id\">éditer</a></p>\n\n";
+      echo "<p><a href=\"/fr/archives.php?id=$row->id\">$row->title</a><br />&#160;&#160;$row->f_timestamp&#160;&#160;|&#160;&#160;<a href=\"edit.php?id=$row->id\">éditer</a></p>\n\n";
     }
   }
   else {
@@ -267,7 +267,7 @@
   }
   if(mysql_num_rows($result) > 0) {
     while($row = mysql_fetch_object($result)) {
-      echo "<p><a href=\"/fr/archives.php?id=$row->id\">$row->title</a><br />&nbsp&nbsp;$row->f_timestamp</p>\n\n";
+      echo "<p><a href=\"/fr/archives.php?id=$row->id\">$row->title</a><br />&#160;&#160;$row->f_timestamp</p>\n\n";
     }
   }
   else {
Index: localized/it/includes/functions.inc
===================================================================
--- localized/it/includes/functions.inc	(revision 34838)
+++ localized/it/includes/functions.inc	(working copy)
@@ -128,7 +128,7 @@
   if(!$_POST['submit']) {
     echo "<p>Use the form below to add project news.</p>\n\n";
     echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
-    echo "<p>Title:&nbsp;&nbsp;<input type=\"text\" name=\"title\" size=\"40\" /></p>\n";
+    echo "<p>Title:&#160;&#160;<input type=\"text\" name=\"title\" size=\"40\" /></p>\n";
     echo "<p>News:</p>\n";
     echo "<p><textarea name=\"news\" cols=\"70\" rows=\"20\"></textarea></p>\n";
     echo "<p><input type=\"submit\" name=\"submit\" value=\"Submit\" /></p>\n";
@@ -184,7 +184,7 @@
       $row = mysql_fetch_object($result);
       echo "<p>Use the form below to edit project news.</p>\n\n";
       echo "<form action=\"$PHP_SELF?id=$id\" method=\"post\">\n";
-      echo "<p>Title:&nbsp;&nbsp;<input type=\"text\" name=\"title\" size=\"40\" value=\"$row->title\" /></p>\n";
+      echo "<p>Title:&#160;&#160;<input type=\"text\" name=\"title\" size=\"40\" value=\"$row->title\" /></p>\n";
       echo "<p>News:</p>\n";
       echo "<p><textarea name=\"news\" cols=\"70\" rows=\"20\">";
       echo htmlentities($row->news);
@@ -245,7 +245,7 @@
   }
   if(mysql_num_rows($result) > 0) {
     while($row = mysql_fetch_object($result)) {
-      echo "<p><a href=\"/it/archives.php?id=$row->id\">$row->title</a><br />&nbsp&nbsp;$row->f_timestamp&nbsp;&nbsp;|&nbsp;&nbsp;<a href=\"edit.php?id=$row->id\">edit</a></p>\n\n";
+      echo "<p><a href=\"/it/archives.php?id=$row->id\">$row->title</a><br />&#160;&#160;$row->f_timestamp&#160;&#160;|&#160;&#160;<a href=\"edit.php?id=$row->id\">edit</a></p>\n\n";
     }
   }
   else {
@@ -267,7 +267,7 @@
   }
   if(mysql_num_rows($result) > 0) {
     while($row = mysql_fetch_object($result)) {
-      echo "<p><a href=\"/it/archives.php?id=$row->id\">$row->title</a><br />&nbsp&nbsp;$row->f_timestamp</p>\n\n";
+      echo "<p><a href=\"/it/archives.php?id=$row->id\">$row->title</a><br />&#160;&#160;$row->f_timestamp</p>\n\n";
     }
   }
   else {
Index: install.php
===================================================================
--- install.php	(revision 34838)
+++ install.php	(working copy)
@@ -17,7 +17,7 @@
     </p>
 
     <ul>
-        <li>&ldquo;dmg&rdquo; disk images for <a href="<?php print $leopard_dmg; ?>">Leopard (Universal)</a>, <a
+        <li>&#8220;dmg&#8221; disk images for <a href="<?php print $leopard_dmg; ?>">Leopard (Universal)</a>, <a
         href="<?php print $tiger_dmg; ?>">Tiger (Universal)</a> and <a href="<?php print $panther_dmg; ?>">Panther (PowerPC)
         </a> as a legacy platform, containing pkg installers for use with the Mac OS X Installer. By far the simplest installation
         procedure that most users should <a href="#pkg">follow</a> after meeting the requirements listed <a href="#requirements">
@@ -43,14 +43,14 @@
             <li>Apple's <a href="https://connect.apple.com/cgi-bin/WebObjects/MemberSite.woa/wa/getSoftware?bundleID=19897">
             Xcode 3.0</a> Developer Tools for the Leopard platform or 2.4.1 for Tiger, found at the <a href="http://developer.apple.com/tools/xcode/">
             Apple Developer Connection</a> site or on your Mac OS X installation CDs/DVD.</li>
-            <li>The X11 windowing environment (A.K.A. &ldquo;X11 User&rdquo;) and its related SDK package (&ldquo;X11SDK&rdquo;)
+            <li>The X11 windowing environment (A.K.A. &#8220;X11 User&#8221;) and its related SDK package (&#8220;X11SDK&#8221;)
             for ports that depend on the functionality they provide to compile and run.
                 <ul>
-                    <li>the &ldquo;X11 User&rdquo; package is an optional installation on your system CDs/DVD for Panther and
-                    Tiger, enabled through the &ldquo;Customize&rdquo; button of the installer, whereas it is included by default
+                    <li>the &#8220;X11 User&#8221; package is an optional installation on your system CDs/DVD for Panther and
+                    Tiger, enabled through the &#8220;Customize&#8221; button of the installer, whereas it is included by default
                     on Leopard.</li>
-                    <li>the &ldquo;X11 SDK&rdquo; package from the Xcode installer will be automatically selected if &ldquo;X11
-                    User&rdquo; is already installed, so be sure to install that first.</li>
+                    <li>the &#8220;X11 SDK&#8221; package from the Xcode installer will be automatically selected if &#8220;X11
+                    User&#8221; is already installed, so be sure to install that first.</li>
                 </ul>
             </li>
         </ol>
@@ -70,8 +70,8 @@
     the installer</a> to include the necessary settings to run MacPorts and the programs it installs, but you may need to
     open a new shell for these changes to take effect.</p>
 
-    <p>The MacPorts &ldquo;<kbd>selfupdate</kbd>&rdquo; command will also be run for you by the installer to ensure you have our
-    latest available release and the latest revisions to the &ldquo;Portfiles&rdquo; that contain the instructions employed
+    <p>The MacPorts &#8220;<kbd>selfupdate</kbd>&#8221; command will also be run for you by the installer to ensure you have our
+    latest available release and the latest revisions to the &#8220;Portfiles&#8221; that contain the instructions employed
     in the building and installation of ports. After installation is done, it is recommended that you run this step manually
     on a regular basis to to keep your MacPorts system always current:</p>
     
@@ -79,7 +79,7 @@
 
     <p>At this point you should be ready to enjoy MacPorts!</p>
 
-    <p>Type &ldquo;<kbd>man port</kbd>&rdquo; at the command line prompt and/or browse over to our <a href="<?php print
+    <p>Type &#8220;<kbd>man port</kbd>&#8221; at the command line prompt and/or browse over to our <a href="<?php print
     $guide_url; ?>">Guide</a> to find out more information about using MacPorts. <a href="#help">Help</a> is also available.
     </p>
 
@@ -91,9 +91,9 @@
 
 
     <ol>
-        <li>&ldquo;<kbd>cd</kbd>&rdquo; into the directory where you downloaded the package and run &ldquo;<kbd>tar xjvf
-        <a href="<?php print $bz2_tarball; ?>">MacPorts-<?php print $macports_version_major; ?>.tar.bz2</a></kbd>&rdquo; or
-        &ldquo;<kbd>tar xzvf <a href="<?php print $gz_tarball; ?>">MacPorts-<?php print $macports_version_major; ?>.tar.gz</a></kbd>&rdquo;,
+        <li>&#8220;<kbd>cd</kbd>&#8221; into the directory where you downloaded the package and run &#8220;<kbd>tar xjvf
+        <a href="<?php print $bz2_tarball; ?>">MacPorts-<?php print $macports_version_major; ?>.tar.bz2</a></kbd>&#8221; or
+        &#8220;<kbd>tar xzvf <a href="<?php print $gz_tarball; ?>">MacPorts-<?php print $macports_version_major; ?>.tar.gz</a></kbd>&#8221;,
         depending on whether you downloaded the bz2 tarball or the gz one, respectively.</li>
         <li>Build and install the recently unpacked sources:
             <ul>
@@ -109,11 +109,11 @@
         </li>
     </ol>
 
-    <p>These steps need to be perfomed from an administrator account, for which &ldquo;<kbd>sudo</kbd>&rdquo; will ask the
+    <p>These steps need to be perfomed from an administrator account, for which &#8220;<kbd>sudo</kbd>&#8221; will ask the
     password upon installation. This procedure will install a pristine MacPorts system and, if the optional steps are taken,
     remove the as of now unnecessary MacPorts-<?php print $macports_version_major; ?> source directory and corresponding tarball.</p>
 
-    <p>To customize your installation you should read the output of &ldquo;<kbd>./configure --help | more</kbd>&rdquo; and
+    <p>To customize your installation you should read the output of &#8220;<kbd>./configure --help | more</kbd>&#8221; and
     pass the appropriate options for the settings you wish to tweak to the configuration script in the steps detailed above.</p>
 	
     <p>You will need to manually adapt your shell's environment to work with MacPorts and your chosen installation <kbd>
@@ -136,8 +136,8 @@
 
     <p>Upon completion MacPorts will be ready to install ports!</p>
 
-    <p>It is recommended to run the above command on a regular basis to keep your installation current. Type &ldquo;<kbd>man
-    port</kbd>&rdquo; at the command line prompt and/or browse over to our <a href="<?php print $guide_url; ?>">Guide</a> to
+    <p>It is recommended to run the above command on a regular basis to keep your installation current. Type &#8220;<kbd>man
+    port</kbd>&#8221; at the command line prompt and/or browse over to our <a href="<?php print $guide_url; ?>">Guide</a> to
     find out more information about using MacPorts. <a href="#help">Help</a> is also available.</p>
 
 
@@ -146,8 +146,8 @@
     <p>If you are developer or a user with a taste for the bleeding edge and wish for the latest changes and feature additions,
     you may acquire the MacPorts sources through SVN.</p>
 
-    <p>Use the following command to check the project's &ldquo;trunk&rdquo; out of the MacPorts anonymous subversion repository,
-    containing all of our source modules (MacPorts' &ldquo;base&rdquo;, the ports tree and all of documentation in raw form):</p>
+    <p>Use the following command to check the project's &#8220;trunk&#8221; out of the MacPorts anonymous subversion repository,
+    containing all of our source modules (MacPorts' &#8220;base&#8221;, the ports tree and all of documentation in raw form):</p>
 
     <pre>svn co <?php print $svn_url . 'trunk'; ?></pre>
 
Index: index.php
===================================================================
--- index.php	(revision 34838)
+++ index.php	(working copy)
@@ -21,7 +21,7 @@
     . '#using'; ?>">compiling and installing</a> open-source software on your Mac.</p>
     
     <p>We provide a single software tree that attempts to track the latest release of every software title (port) we distribute,
-    without splitting them into &ldquo;stable&rdquo; Vs. &ldquo;unstable&rdquo; branches, targetting mainly the current Mac OS
+    without splitting them into &#8220;stable&#8221; Vs. &#8220;unstable&#8221; branches, targetting mainly the current Mac OS
     X release (10.5, A.K.A Leopard) and the immediately previous one (10.4, A.K.A. Tiger). There are currently <a href="ports.php">
     <b><?php print $portsdb_info['num_ports']; ?></b> ports</a> in our tree, distributed among <?php print $portsdb_info['num_categories']; ?>
     different categories, and more are being added on a regular basis.</p>
@@ -43,7 +43,7 @@
     <h3 class="subhdr">Getting involved</h3>
     
     <p>There are many ways you can get involved with MacPorts and peer users, system administrators &amp; developers alike.
-    Browse over to the &ldquo;<a href="contact.php">Contact Us</a>&rdquo; section of our site and:</p>
+    Browse over to the &#8220;<a href="contact.php">Contact Us</a>&#8221; section of our site and:</p>
     
     <ul>
         <li>Explore our <a href="contact.php#Lists">mailing lists</a>, either if it is for some general user support or to 
@@ -55,7 +55,7 @@
     </ul>
 
     <p>If on the other hand you are interested in joining The MacPorts Project in any way, then don't hesitate to contact the
-    project's management team, &ldquo;<a href="contact.php#PortMgr">PortMgr</a>&rdquo;, to explain your particular interest
+    project's management team, &#8220;<a href="contact.php#PortMgr">PortMgr</a>&#8221;, to explain your particular interest
     and present a formal application. We're always looking for more helping hands that can extend and improve our ports tree
     and documentation, or take MacPorts itself beyond its current limitations and into new areas of the vast software packaging
     field. We're eager to hear from you!</p>

Index: contact.php
===================================================================
--- contact.php	(revision 34838)
+++ contact.php	(working copy)
@@ -39,10 +39,10 @@
         <li>Finally, if you still haven't found the answer to your problem, send e-mail to the appropriate mailing list
         with the following information:
             <ul>
-                <li>output generated by the &ldquo;<kbd>port</kbd>&rdquo; command's <kbd>-v</kbd> (verbose) or <kbd>-d</kbd>
+                <li>output generated by the &#8220;<kbd>port</kbd>&#8221; command's <kbd>-v</kbd> (verbose) or <kbd>-d</kbd>
                 (debug) flags;</li>
                 <li>platform details such as operating system version (e.g. 10.4.10) and hardware architecture (e.g. Intel
-                or PowerPC) -- the &ldquo;<kbd>sw_vers</kbd>&rdquo; and &ldquo;<kbd>uname -a</kbd>&rdquo; commands are of
+                or PowerPC) -- the &#8220;<kbd>sw_vers</kbd>&#8221; and &#8220;<kbd>uname -a</kbd>&#8221; commands are of
                 great help in this regard;</li>
                 <li>any third party software that may exist in places such as <kbd>/usr/local</kbd> and/or <kbd>/sw</kbd>.
                 </li>
@@ -62,13 +62,13 @@
         </li>
         <li><a href="http://lists.macosforge.org/mailman/listinfo/macports-dev/">MacPorts Developers</a>
         (<a href="http://lists.macosforge.org/pipermail/macports-dev/">archives</a>):
-            <p>Where project members and contributors discuss the MacPorts &ldquo;base&rdquo; system itself and future
-            development plans, and related &ldquo;Portfile&rdquo; writing best practices. A low volume list.</p>
+            <p>Where project members and contributors discuss the MacPorts &#8220;base&#8221; system itself and future
+            development plans, and related &#8220;Portfile&#8221; writing best practices. A low volume list.</p>
         </li>
         <li><a href="http://lists.macosforge.org/mailman/listinfo/macports-changes/">MacPorts Changes</a>
         (<a href="http://lists.macosforge.org/pipermail/macports-changes/">archives</a>):
             <p>Read-only, low to moderate volume list of changes to our <a href="<?php print $svn_url; ?>">SVN repository</a>
-            for both &rdquo;base&ldquo; code and Portfiles, among others.</p>
+            for both &#8221;base&#8220; code and Portfiles, among others.</p>
         </li>
         <li><a href="http://lists.macosforge.org/mailman/listinfo/macports-tickets/">MacPorts Tickets</a>
         (<a href="http://lists.macosforge.org/pipermail/macports-tickets/">archives</a>):
@@ -91,9 +91,9 @@
 
     <h3 class="subhdr" id="PortMgr">Administrative Contact</h3>
 
-    <p>The private and read-only &ldquo;<?php print obfuscate_email("macports-mgr@lists.macosforge.org"); ?>&rdquo; mailing
+    <p>The private and read-only &#8220;<?php print obfuscate_email("macports-mgr@lists.macosforge.org"); ?>&#8221; mailing
     list is where you should send mail to in case you need to get in touch with the The MacPorts Project's <a href="<?php print
-    $guide_url . '#project.portmgr'; ?>">management team</a> (A.K.A. &ldquo;PortMgr&rdquo;), in case you have any administrative
+    $guide_url . '#project.portmgr'; ?>">management team</a> (A.K.A. &#8220;PortMgr&#8221;), in case you have any administrative
     request or if you wish to discuss anything you might feel is of private nature (like the interaction between MacPorts and
     NDA'd software).</p>
 